@@ -3,23 +3,34 @@
 // Purpose:     About dialog
 // Author:      Alex Thuering
 // Created:     6.11.2003
-// RCS-ID:      $Id: About.cpp,v 1.39 2008/11/11 06:27:59 ntalex Exp $
+// RCS-ID:      $Id: About.cpp,v 1.83 2014/12/31 12:09:48 ntalex Exp $
 // Copyright:  (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include "About.h"
-#include "hyperlink.h"
+#include "Authors.h"
 #include <wxVillaLib/utils.h>
 #include <wx/statline.h>
 #include <wx/notebook.h>
-#include <wx/html/htmlwin.h>
-
+#include <wx/hyperlink.h>
+#include <wx/utils.h>
 #include "rc/logo.png.h"
 
+BEGIN_EVENT_TABLE(About, wxDialog)
+	EVT_HTML_LINK_CLICKED(wxID_ANY, About::OnLinkClicked)
+END_EVENT_TABLE()
+
+wxString FixEmail(const wxString& str) {
+	wxString result = str;
+	result.Replace(wxT(" at "), wxT("@"));
+	result.Replace(wxT("<"), wxT("&lt;"));
+	result.Replace(wxT(">"), wxT("&gt;"));
+	return result;
+}
+
 About::About(wxWindow* parent): wxDialog(parent, -1, wxEmptyString,
-  wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
-{
+		wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER) {
     // sets the application icon
     SetTitle(_("About ..."));
 	
@@ -62,92 +73,72 @@ About::About(wxWindow* parent): wxDialog(parent, -1, wxEmptyString,
 	  _("DVDStyler is a crossplatform authoring system for Video DVD production.")),
 	  0, wxALIGN_CENTER | wxLEFT | wxRIGHT, 10);
     aboutSizer->Add(0, 6);
-    myHyperLink* website = new myHyperLink(aboutPanel, -1, APP_WEBSITE);
+    wxHyperlinkCtrl* website = new wxHyperlinkCtrl(aboutPanel, wxID_ANY, APP_WEBSITE, APP_WEBSITE);
     wxString url = APP_WEBSITE;
     website->SetURL(url);
     aboutSizer->Add(website, 0, wxALIGN_CENTER);
+    
+    // support
+    wxHtmlWindow* supportPanel = new wxHtmlWindow(notebook, -1,
+    		wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxHW_SCROLLBAR_AUTO);
+    wxString page = wxT("<html><body>");
+    page += wxT("<h5>") + wxString(_("Forum")) + wxT("</h5>");
+    page += wxString::Format(_("Please use %sDVDStyler forum%s to get support, ask questions, or discuss this software."),
+    		wxT("<a href=\"http://sourceforge.net/p/dvdstyler/discussion/318795/\" target=\"_blank\">"), wxT("</a>"));
+    page += wxT("<h5>") + wxString(_("WIKI")) + wxT("</h5>");
+    page += wxString::Format(_("Some documentation and %sFAQ%s you can find in %sDVDStyler WIKI%s or you can publish there your comments or small guides."),
+			wxT("<a href=\"http://sourceforge.net/p/dvdstyler/wiki/Home/\" target=\"_blank\">"), wxT("</a>"),
+			wxT("<a href=\"http://sourceforge.net/p/dvdstyler/wiki/Home/\" target=\"_blank\">"), wxT("</a>"));
+    page += wxT("<h5>") + wxString(_("Bugs & RFE")) + wxT("</h5>");
+    page += wxString::Format(_("Please use %sSourceforge Bugtracing system%s to report bug and %sSourceforge RFE system%s to submit a new feature request."),
+    		wxT("<a href=\"http://sourceforge.net/p/dvdstyler/bugs/\" target=\"_blank\">"), wxT("</a>"),
+    		wxT("<a href=\"http://sourceforge.net/p/dvdstyler/feature-requests/\" target=\"_blank\">"), wxT("</a>"));
+    page += wxT("</body></html>");
+    supportPanel->SetPage(page);
+    notebook->AddPage(supportPanel, _("Support"));
 	
 	// authors
 	wxHtmlWindow* authorsPanel = new wxHtmlWindow(notebook, -1,
 	  wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxHW_SCROLLBAR_AUTO);
-	wxString page = _T("<html><body>");
-	page += _T("<font face='Verdana,Arial,Helvetica,sans-serif' size='1'>");
-	page += _T("<table width='100%' cellspacing='1' cellpadding='0' border='0'>");
+	page = _T("<html><body>");
+	page += _T("<table width='100%' cellspacing='2' cellpadding='2' border='0' valign='top'>");
 	
-	page += _T("<tr><td colspan=3><b>");
-	page += _("Author and Maintainer");
-	page += _T("</b></td></tr>");
-	page += _T("<tr><td width='16'>&nbsp;</td><td colspan=2>");
-	page += _T("Alex Th&uuml;ring &lt;alex at thuering.biz&gt;");
+	page += _T("<tr><td colspan='3'><b>") + wxString(_("Author and Maintainer")) + _T("</b></td></tr>");
+	page += _T("<tr><td>&nbsp;</td><td colspan='2'>");
+	page += FixEmail(s_author);
 	page += _T("</td></tr>");
 	
-	page += _T("<tr><td colspan=3>&nbsp;</td></tr>");
-	
-	page += _T("<tr><td colspan=3><b>");
-	page += _("Doc Writer");
-	page += _T("</b></td></tr>");
-	page += _T("<tr><td width='16'>&nbsp;</td><td colspan=2>");
-	page += _T("Don Brett &lt;dlbrett at zoominternet.net&gt;");
+	page += _T("<tr><td colspan='3'><b>") + wxString(_("Doc Writer")) + _T("</b></td></tr>");
+	page += _T("<tr><td>&nbsp;</td><td colspan='2'>");
+	page += FixEmail(s_docWriter);
 	page += _T("</td></tr>");
 	
-	page += _T("<tr><td colspan=3>&nbsp;</td></tr>");
-	
-	page += _T("<tr><td colspan=3><b>");
-	page += _("Packager (.deb)");
-	page += _T("</b></td></tr>");
-	page += _T("<tr><td width='16'>&nbsp;</td><td colspan=2>");
-	page += _T("Uwe Bugla &lt;uwe.bugla at gmx.de&gt;");
-	page += _T("</td></tr>");
-	page += _T("<tr><td width='16'>&nbsp;</td><td colspan=2>");
-	page += _T("Fabrice Coutadeur &lt;coutadeurf at gmail.com&gt;");
+	page += _T("<tr><td colspan='3'><b>") + wxString(_("Packager (.deb)")) + _T("</b></td></tr>");
+	page += _T("<tr><td>&nbsp;</td><td colspan='2'>");
+	page += FixEmail(s_packager);
 	page += _T("</td></tr>");
 	
-	page += _T("<tr><td colspan=3>&nbsp;</td></tr>");
+	page += _T("<tr><td colspan='3'><b>") + wxString(_("Translations")) + _T("</b></td></tr>");
 	
-	page += _T("<tr><td colspan=3><b>");
-	page += _("Translations");
-	page += _T("</b></td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Basque</td><td width='100%'>Piarres Beobide &lt;pi at beobide.net&gt;</td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Catalan</td><td width='100%'>Miguel Canteras &lt;ca at openlang.net&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Czech</td><td width='100%'>Vlastimil Skácel &lt;vlastiks at gmail.com&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Danish</td><td width='100%'>Patrick Fust &lt;patrick_fust at hotmail.com&gt;</td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Dutch</td><td width='100%'>Patrick Vijgeboom &lt;patrick.vijgeboom at wanadoo.nl&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>French</td><td width='100%'>Uwe Bugla</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>German</td><td>Alex Th&uuml;ring &lt;alex at thuering.biz&gt;, Uwe Bugla</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Greek</td><td>Aristotelis Pitaridis &lt;pitaridis at gmail.com&gt;</td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Hungarian</td><td>Faczan Laszlo &lt;faczan at freemail.hu&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Italian</td><td>Roberto Minotti &lt;khazad-dum at mail.orson.it&gt;, Paolo Rampino &lt;akir4d at gmail.com&gt;</td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Japanese</td><td>Montty &lt;montty_jp at yahoo.co.jp&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Polish</td><td>Michal Jusyk &lt;drewnozlasu at o2.pl&gt;</td></tr>"); 
-	page += _T("<tr><td>&nbsp;</td><td>Portuguese</td><td>Henrique Lopes Barone &lt;barone_henrique at yahoo.com.br&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Portuguese (Brazilian)</td><td>Henrique Lopes Barone &lt;barone_henrique at yahoo.com.br&gt;, Marco de Freitas &lt;marcodefreitas at gmail.com&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Russian</td><td>Alex Thuering &lt;alex.thuering at web.de&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Serbian</td><td>CICIC Ivana &lt;ozzii23 at gmail.com&gt;</td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Slovak</td><td>Michal Kovac &lt;deadsock at deadsock.co.uk&gt;</td></tr>");
-	page += _T("<tr><td>&nbsp;</td><td>Spanish</td><td>Redy Rodriguez &lt;redy at telefonica.net&gt;, Fabrice Coutadeur &lt;coutadeurf at gmail.com&gt;</td></tr>");
-//	page += _T("<tr><td>&nbsp;</td><td>Swedish</td><td>Daniel Nylander &lt;po at danielnylander.se&gt;</td></tr>");
+	for (unsigned int i = 0; i < sizeof(s_translations)/sizeof(s_translations[0]); i++)
+		page += wxT("<tr><td>&nbsp;</td><td>") + s_translations[i][0] + wxT("</td><td width='100%'>")
+				+ FixEmail(s_translations[i][1]) + wxT("</td></tr>");
 	
-	page += _T("<tr><td colspan=3>&nbsp;</td></tr>");
-	
-	page += _T("<tr><td colspan=3><b>");
-	page += _("Libraries and Tools");
-	page += _T("</b></td></tr>");
+	page += _T("<tr><td colspan='3'><b>") + wxString(_("Libraries and Tools")) + _T("</b></td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td>wxWidgets</td><td>Julian Smart, Robert Roebling and other</td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td>dvdauthor</td><td>Scott Smith</td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td>cdrtools</td><td>Joerg Schilling</td></tr>");
 	page += _T("<tr><td>&nbsp;</td><td>dvd+rw-tools</td><td>Andy Polyakov</td></tr>");
 	
 	page += _T("</table>");
-	page += _T("</font>");
 	page += _T("</body></html>");
-	authorsPanel->SetPage(page); 
+	authorsPanel->SetPage(page);
 	notebook->AddPage(authorsPanel, _("Authors"));
 	
 	// licence
 	wxHtmlWindow* licencePanel = new wxHtmlWindow(notebook, -1,
 	  wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER|wxHW_SCROLLBAR_AUTO);
 	page = _T("<html><body>");
-	page += _T("<font face='Verdana,Arial,Helvetica,sans-serif' size='1'>");
 	page += _T("<p>");
 	page += _("DVDStyler is <a href='http://www.gnu.org/philosophy/free-sw.html'>free software</a> \
 distributed under <a href='http://www.gnu.org/copyleft/gpl.html'>GNU General Public License (GPL)</a>. \
@@ -161,23 +152,16 @@ OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, \
 WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR \
 IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.");
 	page += _T("</p>");
-	page += _T("</font>");
 	page += _T("</body></html>");
-	licencePanel->SetPage(page); 
+	licencePanel->SetPage(page);
 	notebook->AddPage(licencePanel, _("Licence"));
 	
 	// buttons
 	wxBoxSizer* totalpane = new wxBoxSizer(wxVERTICAL);
-#if wxCHECK_VERSION(2,6,0)
 	totalpane->Add(notebook, 1, wxEXPAND|wxALL, 6);
-#else
-    totalpane->Add(new wxNotebookSizer(notebook), 1, wxEXPAND|wxALL, 6);
-#endif
     wxButton* okButton = new wxButton(this, wxID_OK, _("OK"));
     okButton->SetDefault();
-#if defined(__WXGTK__) && wxCHECK_VERSION(2,5,2) && !wxCHECK_VERSION(2,5,4)
-	okButton->SetSizeHints(-1, okButton->GetSize().GetY()+8);
-#endif
+    okButton->SetFocus();
     totalpane->Add(okButton, 0, wxALIGN_CENTER|wxLEFT|wxRIGHT|wxBOTTOM, 10);
 	
     SetSizerAndFit(totalpane);
@@ -185,3 +169,7 @@ IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.");
 
     ShowModal();
 }
+
+void About::OnLinkClicked(wxHtmlLinkEvent& event) {
+	wxLaunchDefaultBrowser(event.GetLinkInfo().GetHref());
+}
