@@ -3,7 +3,7 @@
 // Purpose:     Main window
 // Author:      Alex Thuering
 // Created:     10.10.2003
-// RCS-ID:      $Id: MainWin.cpp,v 1.184 2014/03/06 19:54:47 ntalex Exp $
+// RCS-ID:      $Id: MainWin.cpp,v 1.190 2015/08/16 19:10:25 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -18,6 +18,7 @@
 #include "SettingsDlg.h"
 #include "Config.h"
 #include "MPEG.h"
+#include "MessageDlg.h"
 #include <wxVillaLib/VerticalToolbar.h>
 #include <wxVillaLib/SingleThumbnailDlg.h>
 #include <wxVillaLib/utils.h>
@@ -50,7 +51,7 @@
 #include "rc/preferences.png.h"
 #include "rc/run.png.h"
 #include "rc/files.png.h"
-#include "rc/add.png.h"
+#include "rc/addVideo.png.h"
 
 #define BACKGROUNDS_DIR wxFindDataDirectory(_T("backgrounds"))
 #define BUTTONS_DIR wxFindDataDirectory(_T("buttons"))
@@ -271,7 +272,6 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 }
 
 MainWin::~MainWin() {
-	m_cache.Clear();
 #ifdef __WXMSW__
 	if (m_taskbarInterface != NULL)
 		m_taskbarInterface->Release();
@@ -306,7 +306,7 @@ void MainWin::set_properties() {
 			_("Burn..."), wxT(""));
 	m_toolbar->AddSeparator();
 #if wxCHECK_VERSION(2,9,0)
-	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(add), wxNullBitmap, wxITEM_DROPDOWN,
+	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(addVideo), wxNullBitmap, wxITEM_DROPDOWN,
 			_("Add File..."), wxT(""));
 	wxMenu* addMenu = new wxMenu;
 	addMenu->Append(MENU_DVD_ADD_FILE_ID, _("&File..."));
@@ -314,7 +314,7 @@ void MainWin::set_properties() {
 	addMenu->Append(MENU_DVD_ADD_TITLES_FROM_DVD_ID, _("Titles from &DVD..."));
 	m_toolbar->SetDropdownMenu(MENU_DVD_ADD_FILE_ID, addMenu);
 #else
-	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(add), wxNullBitmap, wxITEM_NORMAL,
+	m_toolbar->AddTool(MENU_DVD_ADD_FILE_ID,  wxT(""), wxBITMAP_FROM_MEMORY(addVideo), wxNullBitmap, wxITEM_NORMAL,
 			_("Add File..."), wxT(""));
 #endif
 	m_toolbar->Realize();
@@ -328,11 +328,10 @@ void MainWin::set_properties() {
 	
     // dir bar
 #ifdef __WXMAC__
-	const wxSize imageSize(16, 16);
-	m_dirBookImages = new wxImageList(imageSize.x, imageSize.y);
-	m_dirBookImages->Add(wxArtProvider::GetBitmap(wxART_FOLDER, wxART_TOOLBAR, imageSize)
-						 .ConvertToImage().Rotate90().Rotate90());
-	m_dirBook->SetImageList(m_dirBookImages);
+//	const wxSize imageSize(16, 16);
+//	m_dirBookImages = new wxImageList(imageSize.x, imageSize.y);
+//	m_dirBookImages->Add(wxArtProvider::GetBitmap(wxART_FOLDER, wxART_TOOLBAR, imageSize).ConvertToImage().Rotate90().Rotate90());
+//	m_dirBook->SetImageList(m_dirBookImages);
 	m_dirBook->AddPage(new wxPanel(m_dirBook), _("File browser"), false, 0);
 	m_dirBook->AddPage(new wxPanel(m_dirBook), _("Backgrounds"));
 	m_dirBook->AddPage(new wxPanel(m_dirBook), _("Buttons"));
@@ -397,7 +396,7 @@ void MainWin::ShowDirTree(bool show) {
 		m_dirTree->Show(true);
 	} else if (!show && m_splitterDir->IsSplit()) {
 		m_splitterDirSash = m_splitterDir->GetSashPosition();
-
+#ifndef __WXMAC__
 		// animate unsplitting
 		m_dirTree->Freeze();
 		wxStopWatch sw;
@@ -411,6 +410,7 @@ void MainWin::ShowDirTree(bool show) {
 				step = sw.Time();
 			pos -= int(step);
 		}
+#endif
 		m_splitterDir->Unsplit(m_dirTree);
 		m_dirTree->SetSize(0, 0);
 		m_dirTree->Thaw();
@@ -664,6 +664,7 @@ void MainWin::OnClose(wxCloseEvent &event) {
 		event.Veto();
 		return;
 	}
+	m_cache.ShowClearPrompt(this);
 	if (!IsIconized())
 		s_config.SetMainWinLocation(GetRect(), IsMaximized());
 	Destroy();
@@ -685,7 +686,9 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 		m_dvd->SetAudioFormat(audioFormat);
 		m_dvd->SetAspectRatio(aspectRatio);
 		m_dvd->SetDefPostCommand(defPostCommand);
-		if (m_dvd->GetTitlesets().size() && m_dvd->GetTitlesets()[0]->GetMenus().size()) {
+		if (m_dvd->GetTitlesets().size() == 0)
+			m_dvd->AddTitleset();
+		if (m_dvd->GetTitlesets()[0]->GetMenus().size()) {
 			// move menus to VMG
 			Menus& menus = m_dvd->GetTitlesets()[0]->GetMenus();
 			Menus& vmMenus = m_dvd->GetVmgm();
@@ -790,7 +793,9 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 	}
 	UpdateDVD();
 	SetChanged(false);
-	m_cache.Clear();
+	if (s_config.GetCacheClearPrompt() == 1) {
+		m_cache.Clear();
+	}
 }
 
 bool MainWin::Open(wxString filename) {
@@ -817,7 +822,9 @@ bool MainWin::Open(wxString filename) {
 	s_config.SetLastProjectDir(m_lastDir);
 	UpdateDVD();
 	SetChanged(false);
-	m_cache.Clear();
+	if (s_config.GetCacheClearPrompt() == 1) {
+		m_cache.Clear();
+	}
 	m_fileHistory.AddFileToHistory(m_dvd->GetFilename());
 	m_fileHistory.Save(*s_config.GetConfigBase());
 
@@ -899,10 +906,29 @@ void MainWin::OnChangedDVD(wxCommandEvent& event) {
 
 void MainWin::DoChangedDVD(bool doUndo) {
 	SetChanged(true, doUndo);
-	wxArrayInt b = m_dvd->CalculateVideoBitrate();
-	long size = m_dvd->GetSize();
-	long total = m_dvd->GetCapacityValue();
-	m_statusbar->SetFillStatus(size, total, b[1], b[2]/60, b[0], m_dvd->IsVideoBitrateAuto(), m_dvd->GetAudioBitrate());
+	long encSize, encDuration, fixSize, fixDuration, fixAvgBitrate;
+	m_dvd->CalculateVideoBitrate(encSize, encDuration, fixSize, fixDuration, fixAvgBitrate);
+	long sizeTotal = m_dvd->GetCapacityValue();
+	int videoBitrate = m_dvd->GetVideoBitrate();
+	int audioBitrate = m_dvd->GetAudioBitrate();
+	
+	int bitrateForTotal = videoBitrate + audioBitrate;
+	if (m_dvd->IsVideoBitrateAuto()) {
+		if (encDuration == 0 && fixDuration > 0) {
+			bitrateForTotal = fixAvgBitrate;
+		}
+		if (bitrateForTotal > 4500)
+			bitrateForTotal = 4500;
+	}
+	
+	int dur = fixDuration/60 + encDuration/60;
+	int durTotal = sizeTotal > 0 ? fixDuration/60 + (sizeTotal-fixSize)*8/bitrateForTotal/60 : 0;
+	
+	// If video bitrate doesn't set to auto, display selected bitrate. 
+	// Else if video must be encoded, display calculated bitrate that will be used for encoding.
+	// Else if video will be copied without encoding, display average bitrate of all video files.
+	// Else if no titles exits, display 8 MB/s
+	m_statusbar->SetFillStatus(dur, durTotal, encDuration == 0 && fixDuration > 0 ? fixAvgBitrate : videoBitrate);
 	m_menuEditor->ShowSafeTV();
 	m_menuEditor->Refresh();
 }
@@ -1223,7 +1249,7 @@ void MainWin::OnAddChapterMenu(wxCommandEvent& event) {
 }
 
 void MainWin::OnAddChapterMenuUpdateUI(wxUpdateUIEvent& event) {
-	event.Enable(m_dvd->GetTitleMenuTemplate() != NULL);
+	event.Enable(m_dvd->GetTitleMenuTemplate() != NULL && m_dvd->GetTitlesets().size() > 0);
 }
 
 void MainWin::OnAddVmMenu(wxCommandEvent& event) {
