@@ -3,7 +3,7 @@
 // Purpose:     The widget to edit a DVD Menu
 // Author:      Alex Thuering
 // Created:     11.10.2003
-// RCS-ID:      $Id: MenuEditor.cpp,v 1.73 2014/02/18 17:03:05 ntalex Exp $
+// RCS-ID:      $Id: MenuEditor.cpp,v 1.81 2015/02/15 19:37:39 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -290,7 +290,7 @@ MenuEditor::MenuEditor(wxWindow *parent, wxWindowID id): wxSVGCtrl(parent, id, w
 		wxWANTS_CHARS), m_gridColour(255, 255, 255) {
 	m_dvd = NULL;
 	m_menu = NULL;
-	objectIsMoving = false;
+	m_doAction = false;
 	DoSelect();
 	m_safeTV = true;
 	m_showGrid = false;
@@ -389,15 +389,7 @@ MenuEditor::MenuEditor(wxWindow *parent, wxWindowID id): wxSVGCtrl(parent, id, w
 }
 
 void MenuEditor::SetMenu(DVD* dvd, Menu* menu, int tsi, int pgci) {
-	if (m_menu != NULL && m_doc != NULL) {
-		// remove old selection
-		for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
-			wxSVGRectElement* selRect = (wxSVGRectElement*) m_doc->GetElementById(wxT("selection_") + *it);
-			if (selRect)
-				selRect->GetParent()->RemoveChild(selRect);
-		}
-		m_selectedIds.clear();
-	}
+	DoSelect();
 	m_dvd = dvd;
 	m_menu = menu;
 	m_tsi = tsi;
@@ -489,7 +481,7 @@ bool MenuEditor::AddButton(wxString fname, int x, int y, int pgci, int tsi, bool
 	}
 
 	wxString param;
-	tsi = tsi >= -1 ? tsi : m_tsi >= -1 ? m_tsi : 0;
+	tsi = tsi >= -1 ? tsi : (m_tsi > -1 || (m_tsi == -1 && isMenu) ? m_tsi : 0);
 
 	MenuObject tmpObj(NULL, false, fname);
 	MenuObjectParam* initParam = tmpObj.GetInitParam();
@@ -579,11 +571,18 @@ wxString MenuEditor::HitTest(int x, int y) {
 			continue;
 		}
 		if (child->GetType() == wxSVGXML_ELEMENT_NODE && child->GetDtd() == wxSVG_USE_ELEMENT) {
+			wxSVGPoint p = wxSVGPoint(x, y);
+			if (child->GetTransform().GetBaseVal().size() > 0) {
+				wxSVGMatrix matrix;
+				child->UpdateMatrix(matrix);
+				p = p.MatrixTransform(matrix.Inverse());
+			}
 			wxSVGRect bbox = child->GetBBox();
 			if (!bbox.IsEmpty()
-					&& x >= bbox.GetX() && x <= bbox.GetX() + bbox.GetWidth()
-					&& y >= bbox.GetY() && y <= bbox.GetY() + bbox.GetHeight())
+					&& p.GetX() >= bbox.GetX() && p.GetX() <= bbox.GetX() + bbox.GetWidth()
+					&& p.GetY() >= bbox.GetY() && p.GetY() <= bbox.GetY() + bbox.GetHeight()) {
 				id = child->GetId();
+			}
 		}
 		child = (wxSVGUseElement*) child->GetNext();
 	}
@@ -591,41 +590,44 @@ wxString MenuEditor::HitTest(int x, int y) {
 }
 
 void MenuEditor::DoSelect(wxString id, bool refresh, bool sendEvent, bool ctrlDown) {
-	if (!m_menu)
+	if (!m_menu || !m_doc) {
+		m_selectedIds.clear();
 		return;
+	}
 	
+	// remove old selection
 	if (!ctrlDown) {
-		// remove old selection
 		wxRect rect;
 		for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
 			wxSVGRectElement* selRect = (wxSVGRectElement*) m_doc->GetElementById(wxT("selection_") + *it);
 			if (selRect) {
 				if (refresh)
-					rect.Union(ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY()));
+					rect.Union(ScaleRect(selRect->GetBBox(wxSVG_COORDINATES_VIEWPORT), GetScaleX(), GetScaleY())
+							.Inflate(8));
 				selRect->GetParent()->RemoveChild(selRect);
 			}
 		}
 		m_selectedIds.clear();
 		if (refresh && !rect.IsEmpty())
 			RefreshRect(rect.Inflate(8));
-	}
+	} 
 	
 	if (m_selectedIds.Index(id) != wxNOT_FOUND) {
-		// remove old selection
 		wxSVGRectElement* selRect = (wxSVGRectElement*) m_doc->GetElementById(wxT("selection_") + id);
 		if (selRect) {
 			if (refresh)
-				RefreshRect(ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY()).Inflate(8));
+				RefreshRect(ScaleRect(selRect->GetBBox(wxSVG_COORDINATES_VIEWPORT), GetScaleX(), GetScaleY())
+						.Inflate(8));
 			selRect->GetParent()->RemoveChild(selRect);
 		}
 		m_selectedIds.Remove(id);
 		return;
 	}
-	if (id.length())
-		m_selectedIds.push_back(id);
-
-	// create selection rectangle
+	
+	// select
 	if (id.length()) {
+		m_selectedIds.push_back(id);
+		// create selection rectangle
 		wxRect rect = CreateSelection(id);
 		if (refresh && !rect.IsEmpty())
 			RefreshRect(rect.Inflate(8));
@@ -651,12 +653,12 @@ wxRect MenuEditor::UpdateSelectionRect(int x, int y) {
 		selRect->SetHeight(1);
 		m_doc->GetRootElement()->AppendChild(selRect);
 	} else
-		refreshRect = ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY());
+		refreshRect = ScaleRect(selRect->GetBBox(wxSVG_COORDINATES_VIEWPORT), GetScaleX(), GetScaleY());
 	selRect->SetWidth(x - selRect->GetX().GetAnimVal().GetValue());
 	selRect->SetHeight(y - selRect->GetY().GetAnimVal().GetValue());
 	selRect->SetCanvasItem(NULL);
 	
-	return refreshRect.Union(ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY()));
+	return refreshRect.Union(ScaleRect(selRect->GetBBox(wxSVG_COORDINATES_VIEWPORT), GetScaleX(), GetScaleY()));
 }
 
 wxRect MenuEditor::PerformSelection() {
@@ -664,7 +666,7 @@ wxRect MenuEditor::PerformSelection() {
 	if (selRectElem == NULL) {
 		return wxRect(0, 0, 0, 0);
 	}
-	wxSVGRect bbox = selRectElem->GetBBox();
+	wxSVGRect bbox = selRectElem->GetBBox(wxSVG_COORDINATES_VIEWPORT);
 	wxRect selRect = wxRect((int) bbox.GetX(), (int) bbox.GetY(), (int) bbox.GetWidth(), (int) bbox.GetHeight());
 	wxRect refreshRect = ScaleRect(bbox, GetScaleX(), GetScaleY());;
 	selRectElem->GetParent()->RemoveChild(selRectElem);
@@ -696,14 +698,19 @@ wxRect MenuEditor::CreateSelection(wxString id) {
 		selRect->SetFill(wxSVGPaint());
 		m_doc->GetRootElement()->AppendChild(selRect);
 	} else
-		refreshRect = ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY());
-	selRect->SetX(obj->GetX());
-	selRect->SetY(obj->GetY());
-	selRect->SetWidth(obj->GetWidth());
-	selRect->SetHeight(obj->GetHeight());
+		refreshRect = ScaleRect(selRect->GetBBox(wxSVG_COORDINATES_VIEWPORT), GetScaleX(), GetScaleY());
+	wxRect bbox = obj->GetBBox();
+	selRect->SetX(bbox.GetX());
+	selRect->SetY(bbox.GetY());
+	selRect->SetWidth(bbox.GetWidth());
+	selRect->SetHeight(bbox.GetHeight());
+	if (obj->GetAngle() != 0 && obj->GetObjectParam(wxT("rotation")) == NULL) {
+		selRect->SetTransform(wxSVGAnimatedTransformList());
+		selRect->Rotate(obj->GetAngle(), bbox.GetX() + bbox.GetWidth()/2, bbox.GetY() + bbox.GetHeight()/2);
+	}
 	selRect->SetCanvasItem(NULL);
 	
-	return refreshRect.Union(ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY()));
+	return refreshRect.Union(ScaleRect(selRect->GetBBox(wxSVG_COORDINATES_VIEWPORT), GetScaleX(), GetScaleY()));
 }
 
 void MenuEditor::RefreshSelected() {
@@ -719,13 +726,15 @@ void MenuEditor::OnMouseLeftButton(wxMouseEvent &event) {
 		event.Skip();
 		return;
 	}
-	if (objectIsMoving) {
-		objectIsMoving = false;
-		if (!event.LeftDown() && m_action == eaNONE) {
-			wxRect rect = PerformSelection();
-			RefreshRect(rect.Inflate(8));
-		}
-		SendChangedEvent();
+	if (!event.LeftDown() && m_action == eaSELECT_RECT) {
+		wxRect rect = PerformSelection();
+		RefreshRect(rect.Inflate(8));
+		return;
+	}
+	if (m_doAction) {
+		m_doAction = false;
+		if (m_action != eaNONE && m_action != eaSELECT && m_action != eaSELECT_RECT)
+			SendChangedEvent();
 	}
 	int x = event.GetX();
 	int y = event.GetY();
@@ -740,6 +749,10 @@ void MenuEditor::OnMouseLeftButton(wxMouseEvent &event) {
 		// change mouse cursor
 		event.m_leftDown = false;
 		OnMouseMove(event);
+		if (GetSelectedIds().size() > 0) {
+			m_action = eaSELECT;
+			m_doAction = true;
+		}
 	}
 	m_copied = false;
 	event.Skip();
@@ -767,25 +780,33 @@ void MenuEditor::OnMouseMove(wxMouseEvent &event) {
 	}
 
 	// left mouse button is down => move, resize or select
-	if (m_action == eaMOVE) { // move
-		// move Object
+	if (m_action == eaMOVE || m_action == eaSELECT) { // move Object
 		int x1 = x - m_oldx;
 		int y1 = y - m_oldy;
 		if (MoveObject(x1, y1)) {
 			RefreshSelected();
-			objectIsMoving = true;
+			m_doAction = true;
 		}
 		m_oldx += x1;
 		m_oldy += y1;
-	} else if (m_action == eaNONE) { // select
+		m_action = eaMOVE;
+	} else if (m_action == eaROTATE) { //rotate Object
+		if (RotateObject(x, y)) {
+			RefreshSelected();
+			m_doAction = true;
+			m_oldx = x;
+			m_oldy = y;
+		}
+	} else if (m_action == eaNONE || m_action == eaSELECT_RECT) { // rectangle selection
 		wxRect rect = UpdateSelectionRect(x, y);
 		RefreshRect(rect.Inflate(8));
-		objectIsMoving = true;
+		m_action = eaSELECT_RECT;
+		m_doAction = true;
 	} else { // m_action=TL,TR,BL,BR => resize
 		// resize object
 		if (ResizeObject(x, y, m_action)) {
 			DoSelect(GetSelected(), true); // refresh
-			objectIsMoving = true;
+			m_doAction = true;
 		}
 	}
 }
@@ -823,9 +844,17 @@ EditorAction MenuEditor::GetEditorAction(int x, int y) {
 	if (!obj)
 		return eaNONE;
 	
+	if (obj->GetAngle() != 0) {
+		wxSVGMatrix matrix;
+		obj->UpdateMatrix(matrix);
+		wxSVGPoint p(x / GetScaleX(), y / GetScaleY());
+		p = p.MatrixTransform(matrix.Inverse());
+		x = (int) round(p.GetX() * GetScaleX());
+		y = (int) round(p.GetY() * GetScaleY());
+	}
+	
 	wxRect rect = ScaleRect(obj->GetBBox(), GetScaleX(), GetScaleY());
-	wxRect rect2 = rect;
-	rect2.Deflate(3, 3);
+	wxRect rect2 = ((const wxRect) rect).Deflate(rect.GetWidth() > 24 ? 4 : 2, rect.GetHeight() > 24 ? 4 : 2);
 	if (!rect2.Contains(x, y)) {
 		int x1 = rect.x + rect.width / 2;
 		int y1 = rect.y + rect.height / 2;
@@ -838,25 +867,36 @@ EditorAction MenuEditor::GetEditorAction(int x, int y) {
 		else if ((x > x1) && (y > y1))
 			return eaRESIZE_BR; // bottom-right
 	}
-
+	if (rect2.GetWidth() > 8 && rect2.GetHeight() > 8) {
+		wxRect rectMove1 = ((const wxRect) rect2).Deflate(rect2.GetWidth() > 24 ? 8 : 4, 0);
+		wxRect rectMove2 = ((const wxRect) rect2).Deflate(0, rect2.GetHeight() > 24 ? 8 : 4);
+		if (!rectMove1.Contains(x, y) && !rectMove2.Contains(x, y)) {
+			return eaROTATE;
+		}
+	}
 	return eaMOVE; // inside of the selected object
 }
 
 void MenuEditor::SetMouseCursor(EditorAction tt) {
 	switch (tt) {
-		case eaNONE: SetCursor(wxCursor(wxCURSOR_ARROW)); break;
+		case eaNONE:
+		case eaSELECT_RECT: SetCursor(wxCursor(wxCURSOR_ARROW)); break;
 #ifdef __WXMSW__
-		case eaMOVE: SetCursor(wxCursor(_T("wxCURSOR_MOVE"),wxBITMAP_TYPE_CUR_RESOURCE)); break;
+		case eaMOVE:
+		case eaSELECT: SetCursor(wxCursor(_T("wxCURSOR_MOVE"),wxBITMAP_TYPE_CUR_RESOURCE)); break;
 		case eaRESIZE_TL:
 		case eaRESIZE_BR: SetCursor(wxCursor(wxCURSOR_SIZENWSE)); break;
 		case eaRESIZE_TR:
 		case eaRESIZE_BL: SetCursor(wxCursor(wxCURSOR_SIZENESW)); break;
+		case eaROTATE: SetCursor(wxCursor(_T("wxCURSOR_ROTATE"),wxBITMAP_TYPE_CUR_RESOURCE)); break;
 #else
-		case eaMOVE: SetCursor(wxImage(CURSOR_FILE(_T("move.cur"))));break;
+		case eaMOVE:
+		case eaSELECT: SetCursor(wxImage(CURSOR_FILE(_T("move.cur"))));break;
 		case eaRESIZE_TL:
 		case eaRESIZE_BR: SetCursor(wxImage(CURSOR_FILE(_T("nwse.cur"))));break;
 		case eaRESIZE_TR:
 		case eaRESIZE_BL: SetCursor(wxImage(CURSOR_FILE(_T("nesw.cur"))));break;
+		case eaROTATE: SetCursor(wxImage(CURSOR_FILE(_T("rotate.cur"))));break;
 #endif
 	}
 }
@@ -954,6 +994,22 @@ bool MenuEditor::MoveObjectInt(int& x, int& y) {
 	return true;
 }
 
+bool MenuEditor::RotateObject(int x, int y) {
+	if (m_selectedIds.size() != 1)
+		return false;
+	x = (int) round(x / GetScaleX());
+	y = (int) round(y / GetScaleY());
+	int oldx = (int) round(m_oldx / GetScaleX());
+	int oldy = (int) round(m_oldy / GetScaleY());
+	MenuObject* obj = m_menu->GetObject(m_actionObject);
+	int cx = obj->GetX() + obj->GetWidth() / 2;
+	int cy = obj->GetY() + obj->GetHeight() / 2;
+	double angleOld = atan2(oldx - cx, oldy - cy) / M_PI * 180;
+	double angleNew = atan2(x - cx, y - cy) / M_PI * 180;
+	obj->SetAngle(obj->GetAngle() + angleOld - angleNew);
+	return true;
+}
+
 bool MenuEditor::ResizeObject(int x, int y, EditorAction action) {
 	x = (int) round(x/GetScaleX());
 	y = (int) round(y/GetScaleY());
@@ -979,6 +1035,15 @@ bool MenuEditor::ResizeObjectInt(int x, int y, EditorAction action) {
 	if ((action == eaRESIZE_TL || action == eaRESIZE_TR)
 			&& y > (int) m_doc->GetRootElement()->GetHeight().GetBaseVal() - 8)
 		y = (int) m_doc->GetRootElement()->GetHeight().GetBaseVal() - 8;
+	
+	if (obj->GetAngle() != 0) {
+		wxSVGMatrix matrix;
+		obj->UpdateMatrix(matrix);
+		wxSVGPoint p(x, y);
+		p = p.MatrixTransform(matrix.Inverse());
+		x = p.GetX();
+		y = p.GetY();
+	}
 
 	int sx, sy;
 
@@ -1009,10 +1074,7 @@ bool MenuEditor::ResizeObjectInt(int x, int y, EditorAction action) {
 	rect.height = sy;
 
 	if (obj->GetBBox() != rect) {
-		obj->SetX(rect.x);
-		obj->SetY(rect.y);
-		obj->SetWidth(rect.width);
-		obj->SetHeight(rect.height);
+		obj->SetRect(rect);
 		return true;
 	}
 	return false;
@@ -1104,6 +1166,8 @@ void MenuEditor::ShowGrid() {
 void MenuEditor::OnMouseDClick(wxMouseEvent& event) {
 	wxCommandEvent evt;
 	OnProperties(evt);
+	m_action = eaMOVE;
+	SetMouseCursor(m_action);
 }
 
 void MenuEditor::OnKeyDown(wxKeyEvent& event) {
