@@ -3,7 +3,7 @@
 // Purpose:     The widget to edit a DVD Menu
 // Author:      Alex Thuering
 // Created:	11.10.2003
-// RCS-ID:      $Id: MenuEditor.h,v 1.11 2009/06/14 16:56:12 ntalex Exp $
+// RCS-ID:      $Id: MenuEditor.h,v 1.28 2014/08/27 17:11:14 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -14,13 +14,14 @@
 #include <wxSVG/svgctrl.h>
 #include "DVD.h"
 class TitlesetManager;
+class MenuObject;
 
-enum TransformType
-{ ttOut, ttIn, ttTL, ttTR, ttBL, ttBR };
+enum EditorAction {
+	eaNONE, eaMOVE, eaRESIZE_TL, eaRESIZE_TR, eaRESIZE_BL, eaRESIZE_BR, eaROTATE, eaSELECT, eaSELECT_RECT
+};
 
-class MenuEditor: public wxSVGCtrl
-{
-  public:
+class MenuEditor: public wxSVGCtrl {
+public:
     MenuEditor(wxWindow *parent, wxWindowID id = -1);
     
     void SetTitlesetManager(TitlesetManager* tm) { m_titlesetManager = tm; }
@@ -36,9 +37,10 @@ class MenuEditor: public wxSVGCtrl
 	bool AddImage(wxString fname, int x = 0, int y = 0);
 	bool AddText(wxString text, int x = 0, int y = 0);
     bool AddObject(wxString fname, int x = 0, int y = 0);
-	bool AddButton(wxString fname, int x, int y, int assignToTitle = -1, int tsi = -1);
+	bool AddButton(wxString fname, int x, int y, int pgci = 0, int tsi = -2, bool isMenu = false, int chapter = 0);
 	
-	wxString GetSelected() { return m_selected; }
+	wxString GetSelected() { return m_selectedIds.size() > 0 ? m_selectedIds[0] : wxT(""); }
+	const wxArrayString& GetSelectedIds() { return m_selectedIds; }
     void Select(wxString id) { DoSelect(id, true, true); }
 	
 	wxString GetPointed() { return m_pointed; }
@@ -60,7 +62,7 @@ class MenuEditor: public wxSVGCtrl
     
     wxString HitTest(int x, int y);
     
-  private:
+private:
     TitlesetManager* m_titlesetManager;
 	DVD*  m_dvd;
 	Menu* m_menu;
@@ -68,40 +70,43 @@ class MenuEditor: public wxSVGCtrl
 	int m_pgci;
 	wxMenu* m_pmenu;
 	wxMenu* m_objMenu;
-	wxMenu* m_viewMenu;
 	wxMenu* m_gridMenu;
-	wxMenu* m_addMenu;
-    wxMenu* m_arrangeMenu;
 	wxPoint m_menuPos;
-	wxString m_selected;
+	wxArrayString m_selectedIds;
 	wxString m_pointed;
 	bool m_safeTV;
 	bool m_showGrid;
 	bool m_gridOverObejcts;
 	int m_grid;
-    wxArrayString m_addMenuObjects;
+	wxColour m_gridColour;
+	wxArrayString m_addMenuObjects;
+	
+	EditorAction m_action;
+	bool m_doAction;
+	wxString m_actionObject;
+	int m_oldx, m_oldy;
+	bool m_doCopy;
+	bool m_copied;
+	EditorAction GetEditorAction(int x, int y);
+	void SetMouseCursor(EditorAction tt);
+	int SnapToGrid(int pos);
+	bool MoveObject(int& x, int& y);
+	bool MoveObjectInt(int& x, int& y);
+	bool RotateObject(int x, int y);
+	bool ResizeObject(int x, int y, EditorAction action = eaRESIZE_BR);
+	bool ResizeObjectInt(int x, int y, EditorAction action = eaRESIZE_BR);
     
-    TransformType m_tt;
-    int m_oldx, m_oldy;
-    bool m_copy;
-    TransformType GetTransformType(int x, int y);
-    void SetMouseCursor(TransformType tt);
-    bool MoveObject(int& x, int& y);
-    bool MoveObjectInt(int& x, int& y);
-	bool ResizeObject(int x, int y, TransformType transformType = ttBR);
-    bool ResizeObjectInt(int x, int y, TransformType transformType = ttBR);
+    void DoSelect(wxString id = wxT(""), bool refresh = false, bool sendEvent = false, bool ctrlDown = false);
+    wxRect CreateSelection(wxString id);
+    void RefreshSelected();
     
-    void DoSelect(wxString id = wxT(""), bool refresh = false, bool sendEvent = false);
+    wxRect UpdateSelectionRect(int x, int y);
+    wxRect PerformSelection();
 	
 	void OnMouseLeftButton(wxMouseEvent &event);
     void OnMouseMove(wxMouseEvent &event);
 	void OnMouseRightButton(wxMouseEvent &event);
-	void OnMouseDClick(wxMouseEvent& WXUNUSED(event));
-    
-    /** timer to send changed event */
-    wxTimer m_eventTimer;
-    void StartEventTimer();
-	void OnEventTimer(wxTimerEvent& event);
+	void OnMouseDClick(wxMouseEvent& event);
     
 	void OnKeyDown(wxKeyEvent& event);
 	
@@ -109,6 +114,8 @@ class MenuEditor: public wxSVGCtrl
 	void OnObjectCopy(wxCommandEvent& event);
 	void OnObjectPaste(wxCommandEvent& event);
 	void OnUpdateUIObjectPaste(wxUpdateUIEvent& event);
+	void OnFirstButton(wxCommandEvent& event);
+	void OnUpdateUIFirstButton(wxUpdateUIEvent& event);
 	void OnObjectDelete(wxCommandEvent& event);
     void OnObjectToFront(wxCommandEvent& event);
     void OnObjectForward(wxCommandEvent& event);
@@ -116,14 +123,25 @@ class MenuEditor: public wxSVGCtrl
     void OnObjectToBack(wxCommandEvent& event);
     void OnUpdateUIObjectForward(wxUpdateUIEvent& event);
     void OnUpdateUIObjectBackward(wxUpdateUIEvent& event);
+    void OnAlignToCenterMH(wxCommandEvent& event);
+    void OnAlignToCenterMV(wxCommandEvent& event);
+    void OnAlignToCenterH(wxCommandEvent& event);
+    void OnAlignToCenterV(wxCommandEvent& event);
+    void OnAlignToLeft(wxCommandEvent& event);
+    void OnAlignToRight(wxCommandEvent& event);
+    void OnAlignToTop(wxCommandEvent& event);
+    void OnAlignToBottom(wxCommandEvent& event);
+    void OnUpdateUIAlign(wxUpdateUIEvent& event);
 	void OnProperties(wxCommandEvent& event);
+	void OnUpdateUIProperties(wxUpdateUIEvent& event);
 	void OnSafeTV(wxCommandEvent& event);
 	void OnShowGrid(wxCommandEvent& event);
 	void OnShowGridOverObjects(wxCommandEvent& event);
+	void OnGridColour(wxCommandEvent& event);
 	void OnGridMenu(wxCommandEvent& event);
 	void OnAddObject(wxCommandEvent& event);
     
-    void SendChangedEvent();
+    void SendChangedEvent(bool updateAllItems = false);
     DECLARE_EVENT_TABLE()
 };
 
