@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu Object
 // Author:      Alex Thuering
 // Created:	04.11.2006
-// RCS-ID:      $Id: MenuObject.h,v 1.27 2014/02/04 13:37:26 ntalex Exp $
+// RCS-ID:      $Id: MenuObject.h,v 1.33 2015/11/29 17:40:23 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -15,6 +15,8 @@
 #include <wx/image.h>
 #include <wx/dynarray.h>
 #include <wxSVG/SVGLength.h>
+#include <vector>
+using namespace std;
 
 class wxSvgXmlNode;
 class wxSVGDocument;
@@ -23,6 +25,8 @@ class wxSVGUseElement;
 class wxSVGSVGElement;
 class wxSVGImageElement;
 class wxSVGRect;
+class wxSVGMatrix;
+class wxSVGTransformList;
 class Menu;
 class DVD;
 
@@ -39,7 +43,7 @@ struct MenuObjectParam {
   wxString name;
   wxString title;
   wxString type;
-  wxString element; // id of element
+  vector<wxString> element; // id of element
   wxString attribute; // attribute name
   bool changeable; // changed if select the button
   wxColour normalColour;
@@ -88,15 +92,19 @@ public:
     inline wxString GetFileName() { return m_fileName; }
     inline wxString GetTitle() { return m_title; }
     
-    int  GetX();
+    int GetX() const;
     void SetX(int value);
-    int  GetY();
+    int GetY() const;
     void SetY(int value);
-    int  GetWidth();
+    int GetWidth() const;
     void SetWidth(int value);
-    int  GetHeight();
+    int GetHeight() const;
     void SetHeight(int value);
-    wxRect GetBBox();
+    void SetRect(wxRect rect);
+    double GetAngle() const;
+    void SetAngle(double value);
+    wxRect GetBBox() const;
+    wxRect GetResultBBox() const;
     wxRect GetFrameBBox(SubStreamMode mode, bool ignorePadding = false);
 	
 	inline bool IsDefaultSize() { return m_defaultSize; }
@@ -105,23 +113,25 @@ public:
 	inline void SetKeepAspectRatio(bool value = true) { m_keepAspectRatio = value; }
     void FixSize(int& width, int& height);
     void UpdateSize();
+    void UpdateMatrix(wxSVGMatrix& matrix) const;
     
-    int GetObjectParamsCount() { return m_params.Count(); }
-    MenuObjectParam* GetObjectParam(int index) { return m_params[index]; }
-    MenuObjectParam* GetObjectParam(wxString name);
+    int GetObjectParamsCount() const { return m_params.Count(); }
+    MenuObjectParam* GetObjectParam(int index) const { return m_params[index]; }
+    MenuObjectParam* GetObjectParam(wxString name) const;
     MenuObjectParam* GetInitParam();
+    MenuObjectParam* GetImageParam();
     int GetChangebaleColourCount(bool drawButtonsOnBackground);
     const wxSVGLength& GetTextOffset() const { return m_textOffset; }
     
-    wxString GetParam(wxString name, wxString attribute = wxT(""));
+    wxString GetParam(wxString name, wxString attribute = wxT("")) const;
 	void SetParam(wxString name, wxString value, wxString attribute = wxT(""));
-    int GetParamInt(wxString name, wxString attribute = wxT(""));
+    int GetParamInt(wxString name, wxString attribute = wxT("")) const;
 	void SetParamInt(wxString name, int value, wxString attribute = wxT(""));
-	double GetParamDouble(wxString name);
+	double GetParamDouble(wxString name) const;
 	void SetParamDouble(wxString name, double value);
-	wxFont GetParamFont(wxString name);
+	wxFont GetParamFont(wxString name) const;
 	void SetParamFont(wxString name, wxFont value);
-	wxColour GetParamColour(wxString name, MenuButtonState state = mbsNORMAL);
+	wxColour GetParamColour(wxString name, MenuButtonState state = mbsNORMAL) const;
 	void SetParamColour(wxString name, wxColour value, MenuButtonState state = mbsNORMAL);
 	double GetParamVideoClipBegin(const wxString& name);
 	double GetParamVideoDuration(const wxString& name);
@@ -137,6 +147,10 @@ public:
 	inline bool IsCustomVideoFrame() { return m_customVideoFrame; }
 	/** Sets, if custom video frame is selected */
 	inline void SetCustomVideoFrame(bool customVideoFrame) { m_customVideoFrame = customVideoFrame; }
+	/** Returns VOB-ID of displayed frame */
+	inline int GetDisplayVobId() { return m_displayVobId; }
+	/** Sets VOB-ID of displayed frame */
+	inline void SetDisplayVobId(int displayVobId) { m_displayVobId = displayVobId; }
 	
     void ToFront();
     void Forward();
@@ -154,7 +168,9 @@ public:
 	virtual wxSvgXmlNode* GetXML(DVDFileType type, DVD* dvd, SubStreamMode mode = ssmNORMAL, bool withSVG = false);
 	virtual bool PutXML(wxSvgXmlNode* node);
 	
-  private:
+	static void SetImageVideoParams(wxSVGSVGElement* svgElem, const wxString& id, const wxString& filename, long pos,
+			int duration);
+private:
 	Menu* m_menu; // can be null
 	wxString m_id;
 	bool m_button;
@@ -171,6 +187,7 @@ public:
 	wxSVGLength m_textOffset;
 	bool m_displayVideoFrame; // sets if video frame must be displayed
 	bool m_customVideoFrame; // shows if custom video frame is selected
+	int m_displayVobId; // VOB-ID of displayed frame
 	
 	bool m_keepAspectRatio;
 	wxSVGImageElement* m_aspectRatioElem;
@@ -187,7 +204,7 @@ public:
 	wxSVGUseElement* m_use;
 	wxSVGSVGElement* m_symbol;
 	wxSVGSVGElement* AddSymol(wxString id, wxSVGElement* content);
-	void AddUse(wxString id, int x, int y, int width, int height);
+	void AddUse(wxString id, int x, int y, int width, int height, const wxSVGTransformList* transforms = NULL);
 	
 	void SetScale(double scaleX, double scaleY);
 	
@@ -197,6 +214,7 @@ public:
 	void InitSize(wxString value, MenuObjectSize& size);
 	unsigned int CalcSize(MenuObjectSize& size, bool width);
 	bool IsAlignRight(MenuObjectSize& size);
+	void UpdateTransform();
 };
 
 #endif // MENU_OBJECT_H
