@@ -3,13 +3,14 @@
 // Purpose:     The class to store information for slideshow
 // Author:      Alex Thuering
 // Created:	26.06.2005
-// RCS-ID:      $Id: Slideshow.cpp,v 1.13 2014/02/11 14:55:33 ntalex Exp $
+// RCS-ID:      $Id: Slideshow.cpp,v 1.15 2015/10/03 13:29:57 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 //////////////////////////////////////////////////////////////////////////////
 
 #include "Slideshow.h"
 #include "Config.h"
+#include "Utils.h"
 #include <wx/filename.h>
 #include <wxVillaLib/utils.h>
 #include <wxSVGXML/svgxmlhelpr.h>
@@ -182,8 +183,10 @@ wxImage Slideshow::GetImage(int index) {
 	return resImg;
 }
 
+/** Returns total duration of slideshow (sec) */
 int Slideshow::GetResultDuration() {
-	return GetDuration() * GetCount() + (GetCount() - 1);
+	bool transition = GetTransition().length() && GetTransition() != wxT("none");
+	return GetDuration() * GetCount() + (transition ? GetCount() - 1 : 0);
 }
 
 wxSvgXmlNode* Slideshow::GetXML(DVDFileType type, wxSvgXmlNode* node) {
