@@ -3,7 +3,7 @@
 // Purpose:     The list box to display information about streams in given VOB
 // Author:      Alex Thuering
 // Created:     03.05.2009
-// RCS-ID:      $Id: VobListBox.cpp,v 1.26 2013/11/13 19:36:57 ntalex Exp $
+// RCS-ID:      $Id: VobListBox.cpp,v 1.28 2015/01/04 21:25:51 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -15,6 +15,7 @@
 #include "SubtitlePropDlg.h"
 #include "TitlePropDlg.h"
 #include <wx/filedlg.h>
+#include <wx/progdlg.h>
 #include <wx/arrimpl.cpp>
 #include <wxSVG/mediadec_ffmpeg.h>
 #include <wxVillaLib/utils.h>
@@ -363,7 +364,7 @@ void VobListBox::AddAudio(wxString filename) {
 }
 
 void VobListBox::AddSubtitle(wxString filename) {
-	m_vob->GetSubtitles().Add(new TextSub(filename));
+	m_vob->AddSubtitlesFile(filename);
 	// update list box
 	RefreshInfo();
 	RefreshAll();
@@ -555,6 +556,17 @@ void VobListBox::ShowPropDialog(unsigned int streamIdx) {
 		if (idx >= m_vob->GetSubtitles().size())
 			return;
 		TextSub* textsub = m_vob->GetSubtitles()[idx];
+		
+		if (!TextSub::IsFontMapInitialized()) {
+			wxProgressDialog pDlg(wxT("DVDStyler"), _("Please wait..."), 99, this,
+					wxPD_APP_MODAL | wxPD_AUTO_HIDE | wxPD_SMOOTH);
+			pDlg.Show();
+			pDlg.SetFocus();
+			pDlg.Pulse();
+			TextSub::GetFontMap();
+			pDlg.Hide();
+		}
+		
 		SubtitlePropDlg dialog(this, textsub, GetSubtitleLangCode(idx));
 		if (dialog.ShowModal() == wxID_OK) {
 			SetSubtitleLangCode(idx, dialog.GetLangCode());
