@@ -3,7 +3,7 @@
 // Purpose:     DVD Authoring Application
 // Author:      Alex Thuering
 // Created:	10.10.2003
-// RCS-ID:      $Id: dvdstyler.cpp,v 1.67 2014/03/06 20:10:41 ntalex Exp $
+// RCS-ID:      $Id: dvdstyler.cpp,v 1.69 2015/01/02 19:33:46 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -125,6 +125,7 @@ bool DVDStyler::OnInit() {
 		m_locale.Init(lang);
 		m_locale.AddCatalogLookupPathPrefix(LOCALE_DIR);
 		m_locale.AddCatalog(wxT("dvdstyler"));
+		m_locale.AddCatalog(wxT("wxstd"));
 	}
 	
 	// set default video format
@@ -147,7 +148,6 @@ bool DVDStyler::OnInit() {
 #endif
 	
 	wxFfmpegMediaDecoder::Init();
-	wxFfmpegMediaTranscoder::Init();
 	
 #ifdef __WXMAC__
 	// init font config
