@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Encoder
 // Author:      Alex Thuering
 // Created:     04.08.2007
-// RCS-ID:      $Id: mediaenc_ffmpeg.h,v 1.4 2008/10/26 19:42:07 ntalex Exp $
+// RCS-ID:      $Id: mediaenc_ffmpeg.h,v 1.14 2015/09/22 15:14:16 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -12,33 +12,41 @@
 #define WX_FFMPEG_MEDIA_ENCODER_H
 
 #include "mediaenc.h"
+#include <stdint.h>
 
 struct AVFormatContext;
 struct AVStream;
 struct AVFrame;
 struct SwsContext;
 
-class wxFfmpegMediaEncoder: public wxMediaEncoder {
-  public:
-    wxFfmpegMediaEncoder();
+class wxFfmpegMediaEncoder {
+public:
+    wxFfmpegMediaEncoder(int threadCount = 1);
     ~wxFfmpegMediaEncoder();
     
     bool BeginEncode(const wxString& fileName, VideoFormat videoFormat,
-    		AudioFormat audioFormat, int videoBitrate = 6000);
-    bool EncodeImage(wxImage image, int frames = 1);
+    		AudioFormat audioFormat, AspectRatio aspectRatio = ar4_3, int videoBitrate = 6000);
+    bool EncodeImage(wxImage image, int frames, AbstractProgressDialog* progressDialog);
+    bool EncodeAudio(double duration, AbstractProgressDialog* progressDialog);
     void EndEncode();
     
+    void SetGopSize(int gopSize) { m_gopSize = gopSize; }
+    
     static wxString GetBackendVersion();
     
-  private:
+private:
+	int m_threadCount;
+	int m_gopSize;
     AVFormatContext* m_outputCtx;
     AVStream* m_videoStm;
     AVStream* m_audioStm;
-    bool addVideoStream(int codecId, VideoFormat videoFormat, int videoBitrate);
+    int64_t m_nextVideoPts;
+    int64_t m_nextAudioPts;
+    bool addVideoStream(int codecId, VideoFormat videoFormat, AspectRatio aspectRatio, int videoBitrate);
     bool addAudioStream(int codecId);
     
     int16_t* m_samples;
-    uint8_t* m_audioOutbuf;
+    AVFrame* m_audioFrame;
     bool OpenAudioEncoder();
     void CloseAudioEncoder();
     
@@ -52,6 +60,8 @@ class wxFfmpegMediaEncoder: public wxMediaEncoder {
     bool writeAudioFrame();
     /** writes m_picture */
     bool writeVideoFrame();
+    
+    void CloseEncoder();
 };
 
 #endif // WX_FFMPEG_MEDIA_ENCODER_H
